## Version 0.3.0 (May 17th, 2018)
* You can specify a list of ports that can be open with arg "-l".
* Hex digest option available at the moment of server listening.
* Added compatiblity with Python 3.

## Version 0.2.0 (April 28th, 2018)
* Added a list of open ports and a button to stop.
* Angular implemented for interface (partially for now).
* New way to run sokery: sokery run.

## Version 0.2.0 (March 1st, 2018)
* Binary implemented, so you can now run directly

## Version 0.1.9 (July 12th, 2017)
* Implemented proxy packages reception.

## Version 0.1.8 (July 6th, 2017)
* New preloaded ports from args (eg. -l 3123,9123).

## Version 0.1.6 (July 6th, 2017)
* Line breaks are highlighted in packaged received.
* Admin error are propagated to every report client.
* New flag for the client test, which indicates that a break line will be added after the payload. (--br).

## Version 0.1.5 (June 23th 2017)
* New built and standallone sender client. (python -m sokery.client)
* Dark interface.
* Nicer coloring for texts.
* Added origin to packages received.

## Version 0.1.3 (June 12th 2017)
* New option for echoing everything received.

## Version 0.1.3
* Added response messages for errors and success port opening.

## Version 0.1.2
* Autoimplemented module, running in port 4991.
* Fixed index.html access.